@@ -1,4 +1,4 @@
-# Implementtion of a pure-perl on_scope_end for perls > 5.10
+# Implementation of a pure-perl on_scope_end for perls > 5.10
 # (relies on Hash::Util:FieldHash)
 
 package # hide from pause
@@ -7,8 +7,7 @@ package # hide from pause
 use strict;
 use warnings;
 
-use warnings;
-use strict;
+our $VERSION = '0.15';
 
 use Tie::Hash ();
 use Hash::Util::FieldHash 'fieldhash';
@@ -26,7 +25,7 @@ fieldhash my %hh;
 {
   package # hide from pause too
     B::Hooks::EndOfScope::PP::_TieHintHashFieldHash;
-  use base 'Tie::StdHash';
+  use base 'Tie::StdHash';  # in Tie::Hash, in core
   sub DELETE {
     my $ret = shift->SUPER::DELETE(@_);
     B::Hooks::EndOfScope::PP::__invoke_callback($_) for @$ret;
